//#region src/types/type-helpers.d.ts
type AnyString = string & NonNullable<unknown>;
type AnyFunction<TResult = unknown> = (...args: any[]) => TResult;
type Prettify<TObject> = NonNullable<unknown> & { [Key in keyof TObject]: TObject[Key] };
type WriteableLevel = "deep" | "shallow";
/**
 * Makes all properties in an object type writeable (removes readonly modifiers).
 * Supports both shallow and deep modes, and handles special cases like arrays, tuples, and unions.
 * @template TObject - The object type to make writeable
 * @template TVariant - The level of writeable transformation ("shallow" | "deep")
 */
type ArrayOrObject = Record<number | string | symbol, unknown> | unknown[];
type Writeable<TObject, TLevel extends WriteableLevel = "shallow"> = TObject extends readonly [...infer TTupleItems] ? [...{ [Index in keyof TTupleItems]: TLevel extends "deep" ? Writeable<TTupleItems[Index], "deep"> : TTupleItems[Index] }] : TObject extends ArrayOrObject ? { -readonly [Key in keyof TObject]: TLevel extends "deep" ? Writeable<TObject[Key], "deep"> : TObject[Key] } : TObject;
type UnionToIntersection<TUnion> = (TUnion extends unknown ? (param: TUnion) => void : never) extends ((param: infer TParam) => void) ? TParam : never;
type UnmaskType<TValue> = {
  _: TValue;
}["_"];
type Awaitable<TValue> = Promise<TValue> | TValue;
type CommonRequestHeaders = "Access-Control-Allow-Credentials" | "Access-Control-Allow-Headers" | "Access-Control-Allow-Methods" | "Access-Control-Allow-Origin" | "Access-Control-Expose-Headers" | "Access-Control-Max-Age" | "Age" | "Allow" | "Cache-Control" | "Clear-Site-Data" | "Content-Disposition" | "Content-Encoding" | "Content-Language" | "Content-Length" | "Content-Location" | "Content-Range" | "Content-Security-Policy-Report-Only" | "Content-Security-Policy" | "Cookie" | "Cross-Origin-Embedder-Policy" | "Cross-Origin-Opener-Policy" | "Cross-Origin-Resource-Policy" | "Date" | "ETag" | "Expires" | "Last-Modified" | "Location" | "Permissions-Policy" | "Pragma" | "Retry-After" | "Save-Data" | "Sec-CH-Prefers-Color-Scheme" | "Sec-CH-Prefers-Reduced-Motion" | "Sec-CH-UA-Arch" | "Sec-CH-UA-Bitness" | "Sec-CH-UA-Form-Factor" | "Sec-CH-UA-Full-Version-List" | "Sec-CH-UA-Full-Version" | "Sec-CH-UA-Mobile" | "Sec-CH-UA-Model" | "Sec-CH-UA-Platform-Version" | "Sec-CH-UA-Platform" | "Sec-CH-UA-WoW64" | "Sec-CH-UA" | "Sec-Fetch-Dest" | "Sec-Fetch-Mode" | "Sec-Fetch-Site" | "Sec-Fetch-User" | "Sec-GPC" | "Server-Timing" | "Server" | "Service-Worker-Navigation-Preload" | "Set-Cookie" | "Strict-Transport-Security" | "Timing-Allow-Origin" | "Trailer" | "Transfer-Encoding" | "Upgrade" | "Vary" | "Warning" | "WWW-Authenticate" | "X-Content-Type-Options" | "X-DNS-Prefetch-Control" | "X-Frame-Options" | "X-Permitted-Cross-Domain-Policies" | "X-Powered-By" | "X-Robots-Tag" | "X-XSS-Protection" | AnyString;
type CommonAuthorizationHeaders = `${"Basic" | "Bearer" | "Token"} ${string}`;
type CommonContentTypes = "application/epub+zip" | "application/gzip" | "application/json" | "application/ld+json" | "application/octet-stream" | "application/ogg" | "application/pdf" | "application/rtf" | "application/vnd.ms-fontobject" | "application/wasm" | "application/xhtml+xml" | "application/xml" | "application/zip" | "audio/aac" | "audio/mpeg" | "audio/ogg" | "audio/opus" | "audio/webm" | "audio/x-midi" | "font/otf" | "font/ttf" | "font/woff" | "font/woff2" | "image/avif" | "image/bmp" | "image/gif" | "image/jpeg" | "image/png" | "image/svg+xml" | "image/tiff" | "image/webp" | "image/x-icon" | "model/gltf-binary" | "model/gltf+json" | "text/calendar" | "text/css" | "text/csv" | "text/html" | "text/javascript" | "text/plain" | "video/3gpp" | "video/3gpp2" | "video/av1" | "video/mp2t" | "video/mp4" | "video/mpeg" | "video/ogg" | "video/webm" | "video/x-msvideo" | AnyString;
//#endregion
//#region src/auth.d.ts
type ValueOrFunctionResult<TValue> = TValue | (() => TValue);
type ValidAuthValue = ValueOrFunctionResult<Awaitable<string | null | undefined>>;
/**
 * Bearer Or Token authentication
 *
 * The value of `bearer` will be added to a header as
 * `auth: Bearer some-auth-token`,
 *
 * The value of `token` will be added to a header as
 * `auth: Token some-auth-token`,
 */
type BearerOrTokenAuth = {
  type?: "Bearer";
  bearer?: ValidAuthValue;
  token?: never;
} | {
  type?: "Token";
  bearer?: never;
  token?: ValidAuthValue;
};
/**
 * Basic auth
 */
type BasicAuth = {
  type: "Basic";
  username: ValidAuthValue;
  password: ValidAuthValue;
};
/**
 * Custom auth
 *
 * @param prefix - prefix of the header
 * @param authValue - value of the header
 *
 * @example
 * ```ts
 * {
 *  type: "Custom",
 *  prefix: "Token",
 *  authValue: "token"
 * }
 * ```
 */
type CustomAuth = {
  type: "Custom";
  prefix: ValidAuthValue;
  value: ValidAuthValue;
};
type Auth = BearerOrTokenAuth | BasicAuth | CustomAuth;
//#endregion
//#region src/constants/common.d.ts
declare const fetchSpecificKeys: (keyof RequestInit | "duplex")[];
//#endregion
//#region src/types/standard-schema.d.ts
/**
 * The Standard Schema interface.
 * @see https://github.com/standard-schema/standard-schema
 */
interface StandardSchemaV1<Input = unknown, Output = Input> {
  /**
   * The Standard Schema properties.
   */
  readonly "~standard": StandardSchemaV1.Props<Input, Output>;
}
declare namespace StandardSchemaV1 {
  /**
   * The Standard Schema properties interface.
   */
  interface Props<Input = unknown, Output = Input> {
    /**
     * Inferred types associated with the schema.
     */
    readonly types?: Types<Input, Output> | undefined;
    /**
     * Validates unknown input values.
     */
    readonly validate: (value: unknown) => Promise<Result<Output>> | Result<Output>;
    /**
     * The vendor name of the schema library.
     */
    readonly vendor: string;
    /**
     * The version number of the standard.
     */
    readonly version: 1;
  }
  /**
   * The result interface of the validate function.
   */
  type Result<Output> = FailureResult | SuccessResult<Output>;
  /**
   * The result interface if validation succeeds.
   */
  interface SuccessResult<Output> {
    /**
     * The non-existent issues.
     */
    readonly issues?: undefined;
    /**
     * The typed output value.
     */
    readonly value: Output;
  }
  /**
   * The result interface if validation fails.
   */
  interface FailureResult {
    /**
     * The issues of failed validation.
     */
    readonly issues: readonly Issue[];
  }
  /**
   * The issue interface of the failure output.
   */
  interface Issue {
    /**
     * The error message of the issue.
     */
    readonly message: string;
    /**
     * The path of the issue, if any.
     */
    readonly path?: ReadonlyArray<PathSegment | PropertyKey> | undefined;
  }
  /**
   * The path segment interface of the issue.
   */
  interface PathSegment {
    /**
     * The key representing a path segment.
     */
    readonly key: PropertyKey;
  }
  /**
   * The Standard Schema types interface.
   */
  interface Types<Input = unknown, Output = Input> {
    /** The input type of the schema. */
    readonly input: Input;
    /** The output type of the schema. */
    readonly output: Output;
  }
  /**
   * Infers the input type of a Standard Schema.
   */
  type InferInput<Schema extends StandardSchemaV1> = NonNullable<Schema["~standard"]["types"]>["input"];
  /**
   * Infers the output type of a Standard Schema.
   */
  type InferOutput<Schema extends StandardSchemaV1> = NonNullable<Schema["~standard"]["types"]>["output"];
}
//#endregion
//#region src/error.d.ts
type HTTPErrorDetails<TErrorData> = {
  defaultErrorMessage: CallApiExtraOptions["defaultErrorMessage"];
  errorData: TErrorData;
  response: Response;
};
declare class HTTPError<TErrorData = Record<string, unknown>> extends Error {
  errorData: HTTPErrorDetails<TErrorData>["errorData"];
  httpErrorSymbol: symbol;
  isHTTPError: boolean;
  name: "HTTPError";
  response: HTTPErrorDetails<TErrorData>["response"];
  constructor(errorDetails: HTTPErrorDetails<TErrorData>, errorOptions?: ErrorOptions);
  /**
   * @description Checks if the given error is an instance of HTTPError
   * @param error - The error to check
   * @returns true if the error is an instance of HTTPError, false otherwise
   */
  static isError<TErrorData>(error: unknown): error is HTTPError<TErrorData>;
}
type ValidationErrorDetails = {
  issues: readonly StandardSchemaV1.Issue[];
  response: Response | null;
};
declare class ValidationError extends Error {
  errorData: ValidationErrorDetails["issues"];
  name: string;
  response: ValidationErrorDetails["response"];
  validationErrorSymbol: symbol;
  constructor(details: ValidationErrorDetails, errorOptions?: ErrorOptions);
  /**
   * @description Checks if the given error is an instance of HTTPError
   * @param error - The error to check
   * @returns true if the error is an instance of HTTPError, false otherwise
   */
  static isError(error: unknown): error is ValidationError;
}
//#endregion
//#region src/url.d.ts
type AllowedQueryParamValues = UnmaskType<boolean | number | string>;
type Params = UnmaskType<Record<string, AllowedQueryParamValues> | AllowedQueryParamValues[]>;
type Query = UnmaskType<Record<string, AllowedQueryParamValues>>;
type InitURLOrURLObject = string | URL;
interface URLOptions {
  /**
   * Base URL to be prepended to all request URLs
   */
  baseURL?: string;
  /**
   * Resolved request URL
   */
  readonly fullURL?: string;
  /**
   * The url string passed to the callApi instance
   */
  readonly initURL?: string;
  /**
   * The URL string passed to the callApi instance, but normalized (removed any method modifiers etc)
   */
  readonly initURLNormalized?: string;
  /**
   * Parameters to be appended to the URL (i.e: /:id)
   */
  params?: Params;
  /**
   * Query parameters to append to the URL.
   */
  query?: Query;
}
//#endregion
//#region src/validation.d.ts
type InferSchemaResult<TSchema, TFallbackResult = NonNullable<unknown>> = undefined extends TSchema ? TFallbackResult : TSchema extends StandardSchemaV1 ? StandardSchemaV1.InferOutput<TSchema> : TSchema extends AnyFunction<infer TResult> ? Awaited<TResult> : TFallbackResult;
interface CallApiSchemaConfig {
  /**
   * The base url of the schema. By default it's the baseURL of the fetch instance.
   */
  baseURL?: string;
  /**
   * Disables runtime validation for the schema.
   */
  disableRuntimeValidation?: boolean;
  /**
   * If `true`, the original input value will be used instead of the transformed/validated output.
   *
   * This is useful when you want to validate the input but don't want any transformations
   * applied by the validation schema (e.g., type coercion, default values, etc).
   */
  disableValidationOutputApplication?: boolean;
  /**
   * Controls the inference of the method option based on the route modifiers (`@get/`, `@post/`, `@put/`, `@patch/`, `@delete/`).
   *
   * - When `true`, the method option is made required on the type level and is not automatically added to the request options.
   * - When `false` or `undefined` (default), the method option is not required on the type level, and is automatically added to the request options.
   *
   */
  requireHttpMethodProvision?: boolean;
  /**
   * Controls the strictness of API route validation.
   *
   * When true:
   * - Only routes explicitly defined in the schema will be considered valid to typescript
   * - Attempting to call undefined routes will result in type errors
   * - Useful for ensuring API calls conform exactly to your schema definition
   *
   * When false or undefined (default):
   * - All routes will be allowed, whether they are defined in the schema or not
   * - Provides more flexibility but less type safety
   *
   * @default false
   */
  strict?: boolean;
}
interface CallApiSchema {
  /**
   *  The schema to use for validating the request body.
   */
  body?: StandardSchemaV1<Body> | ((body: Body) => Awaitable<Body>);
  /**
   *  The schema to use for validating the response data.
   */
  data?: StandardSchemaV1 | ((data: unknown) => unknown);
  /**
   *  The schema to use for validating the response error data.
   */
  errorData?: StandardSchemaV1 | ((errorData: unknown) => unknown);
  /**
   *  The schema to use for validating the request headers.
   */
  headers?: StandardSchemaV1<HeadersOption | undefined> | ((headers: HeadersOption) => Awaitable<HeadersOption>);
  /**
   *  The schema to use for validating the meta option.
   */
  meta?: StandardSchemaV1<GlobalMeta | undefined> | ((meta: GlobalMeta) => Awaitable<GlobalMeta>);
  /**
   *  The schema to use for validating the request method.
   */
  method?: StandardSchemaV1<MethodUnion | undefined> | ((method: MethodUnion) => Awaitable<MethodUnion>);
  /**
   *  The schema to use for validating the request url parameters.
   */
  params?: StandardSchemaV1<Params | undefined> | ((params: Params) => Awaitable<Params>);
  /**
   *  The schema to use for validating the request url queries.
   */
  query?: StandardSchemaV1<Query | undefined> | ((query: Query) => Awaitable<Query>);
}
declare const routeKeyMethods: ["delete", "get", "patch", "post", "put"];
type RouteKeyMethods = (typeof routeKeyMethods)[number];
type PossibleRouteKey = `@${RouteKeyMethods}/` | AnyString;
type BaseCallApiSchema = Partial<Record<PossibleRouteKey, CallApiSchema>>;
declare const defineSchema: <const TBaseSchema extends BaseCallApiSchema>(baseSchema: TBaseSchema) => Writeable<typeof baseSchema, "deep">;
//#endregion
//#region src/plugins.d.ts
type PluginInitContext<TPluginExtraOptions = unknown> = RequestContext & PluginExtraOptions<TPluginExtraOptions> & {
  initURL: string;
};
type PluginInitResult = Partial<Omit<PluginInitContext, "initURL" | "request"> & {
  initURL: InitURLOrURLObject;
  request: CallApiRequestOptions;
}>;
type PluginHooksWithMoreOptions<TMoreOptions = unknown> = HooksOrHooksArray<never, never, TMoreOptions>;
type PluginHooks<TData = never, TErrorData = never, TMoreOptions = unknown> = HooksOrHooksArray<TData, TErrorData, TMoreOptions>;
interface CallApiPlugin {
  /**
   * Defines additional options that can be passed to callApi
   */
  defineExtraOptions?: (...params: never[]) => unknown;
  /**
   * A description for the plugin
   */
  description?: string;
  /**
   * Hooks / Interceptors for the plugin
   */
  hooks?: PluginHooks;
  /**
   *  A unique id for the plugin
   */
  id: string;
  /**
   * A function that will be called when the plugin is initialized. This will be called before the any of the other internal functions.
   */
  init?: (context: PluginInitContext) => Awaitable<PluginInitResult> | Awaitable<void>;
  /**
   * A name for the plugin
   */
  name: string;
  /**
   *  A version for the plugin
   */
  version?: string;
}
declare const definePlugin: <TPlugin extends CallApiPlugin | AnyFunction<CallApiPlugin>>(plugin: TPlugin) => TPlugin;
//#endregion
//#region src/types/default-types.d.ts
type DefaultDataType = unknown;
type DefaultPluginArray = CallApiPlugin[];
type DefaultThrowOnError = boolean;
//#endregion
//#region src/result.d.ts
type Parser = (responseString: string) => Awaitable<Record<string, unknown>>;
declare const getResponseType: <TResponse>(response: Response, parser: Parser) => {
  arrayBuffer: () => Promise<ArrayBuffer>;
  blob: () => Promise<Blob>;
  formData: () => Promise<FormData>;
  json: () => Promise<TResponse>;
  stream: () => ReadableStream<Uint8Array<ArrayBufferLike>> | null;
  text: () => Promise<string>;
};
type InitResponseTypeMap<TResponse = unknown> = ReturnType<typeof getResponseType<TResponse>>;
type ResponseTypeUnion = keyof InitResponseTypeMap | null;
type ResponseTypeMap<TResponse> = { [Key in keyof InitResponseTypeMap<TResponse>]: Awaited<ReturnType<InitResponseTypeMap<TResponse>[Key]>> };
type GetResponseType<TResponse, TResponseType extends ResponseTypeUnion, TComputedResponseTypeMap extends ResponseTypeMap<TResponse> = ResponseTypeMap<TResponse>> = null extends TResponseType ? TComputedResponseTypeMap["json"] : TResponseType extends NonNullable<ResponseTypeUnion> ? TComputedResponseTypeMap[TResponseType] : never;
type CallApiResultSuccessVariant<TData> = {
  data: NoInfer<TData>;
  error: null;
  response: Response;
};
type PossibleJavaScriptError = UnmaskType<{
  errorData: false;
  message: string;
  name: "AbortError" | "Error" | "SyntaxError" | "TimeoutError" | "TypeError" | AnyString;
  originalError: DOMException | Error | SyntaxError | TypeError;
}>;
type PossibleHTTPError<TErrorData> = UnmaskType<{
  errorData: NoInfer<TErrorData>;
  message: string;
  name: "HTTPError";
  originalError: HTTPError;
}>;
type PossibleValidationError = UnmaskType<{
  errorData: ValidationError["errorData"];
  message: string;
  name: "ValidationError";
  originalError: ValidationError;
}>;
type PossibleJavaScriptOrValidationError = UnmaskType<PossibleJavaScriptError | PossibleValidationError>;
type CallApiResultErrorVariant<TErrorData> = {
  data: null;
  error: PossibleHTTPError<TErrorData>;
  response: Response;
} | {
  data: null;
  error: PossibleJavaScriptOrValidationError;
  response: Response | null;
};
type ResultModeMap<TData = DefaultDataType, TErrorData = DefaultDataType, TResponseType extends ResponseTypeUnion = ResponseTypeUnion, TComputedData = GetResponseType<TData, TResponseType>, TComputedErrorData = GetResponseType<TErrorData, TResponseType>> = UnmaskType<{
  all: CallApiResultSuccessVariant<TComputedData> | CallApiResultErrorVariant<TComputedErrorData>;
  allWithException: CallApiResultSuccessVariant<TComputedData>;
  onlySuccess: CallApiResultErrorVariant<TComputedErrorData>["data"] | CallApiResultSuccessVariant<TComputedData>["data"];
  onlySuccessWithException: CallApiResultSuccessVariant<TComputedData>["data"];
}>;
type ResultModeUnion = keyof ResultModeMap | null;
type GetCallApiResult<TData, TErrorData, TResultMode extends ResultModeUnion, TThrowOnError extends ThrowOnErrorUnion, TResponseType extends ResponseTypeUnion> = TErrorData extends false ? ResultModeMap<TData, TErrorData, TResponseType>["onlySuccessWithException"] : TErrorData extends false | undefined ? ResultModeMap<TData, TErrorData, TResponseType>["onlySuccessWithException"] : TErrorData extends false | null ? ResultModeMap<TData, TErrorData, TResponseType>["onlySuccess"] : null extends TResultMode ? TThrowOnError extends true ? ResultModeMap<TData, TErrorData, TResponseType>["allWithException"] : ResultModeMap<TData, TErrorData, TResponseType>["all"] : TResultMode extends NonNullable<ResultModeUnion> ? ResultModeMap<TData, TErrorData, TResponseType>[TResultMode] : never;
//#endregion
//#region src/stream.d.ts
type StreamProgressEvent = {
  /**
   * Current chunk of data being streamed
   */
  chunk: Uint8Array;
  /**
   * Progress in percentage
   */
  progress: number;
  /**
   * Total size of data in bytes
   */
  totalBytes: number;
  /**
   * Amount of data transferred so far
   */
  transferredBytes: number;
};
declare global {
  interface ReadableStream<R> {
    [Symbol.asyncIterator]: () => AsyncIterableIterator<R>;
  }
}
//#endregion
//#region src/hooks.d.ts
type PluginExtraOptions<TPluginOptions = unknown> = {
  options: Partial<TPluginOptions>;
};
interface Hooks<TData = DefaultDataType, TErrorData = DefaultDataType, TPluginOptions = unknown> {
  /**
   * Hook that will be called when any error occurs within the request/response lifecycle, regardless of whether the error is from the api or not.
   * It is basically a combination of `onRequestError` and `onResponseError` hooks
   */
  onError?: (context: ErrorContext<TErrorData> & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
  /**
   * Hook that will be called just before the request is being made.
   */
  onRequest?: (context: RequestContext & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
  /**
   *  Hook that will be called when an error occurs during the fetch request.
   */
  onRequestError?: (context: RequestErrorContext & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
  /**
   * Hook that will be called when upload stream progress is tracked
   */
  onRequestStream?: (context: RequestStreamContext & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
  /**
   * Hook that will be called when any response is received from the api, whether successful or not
   */
  onResponse?: (context: ResponseContext<TData, TErrorData> & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
  /**
   *  Hook that will be called when an error response is received from the api.
   */
  onResponseError?: (context: ResponseErrorContext<TErrorData> & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
  /**
   * Hook that will be called when download stream progress is tracked
   */
  onResponseStream?: (context: ResponseStreamContext & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
  /**
   * Hook that will be called when a request is retried.
   */
  onRetry?: (response: RetryContext<TErrorData> & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
  /**
   * Hook that will be called when a successful response is received from the api.
   */
  onSuccess?: (context: SuccessContext<TData> & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
  /**
   * Hook that will be called when a validation error occurs.
   */
  onValidationError?: (context: ValidationErrorContext & PluginExtraOptions<TPluginOptions>) => Awaitable<unknown>;
}
type HooksOrHooksArray<TData = DefaultDataType, TErrorData = DefaultDataType, TMoreOptions = unknown> = { [Key in keyof Hooks<TData, TErrorData, TMoreOptions>]: Hooks<TData, TErrorData, TMoreOptions>[Key] | Array<Hooks<TData, TErrorData, TMoreOptions>[Key]> };
type RequestContext = {
  /**
   * Config object passed to createFetchClient
   */
  baseConfig: BaseCallApiExtraOptions & CallApiRequestOptions;
  /**
   * Config object passed to the callApi instance
   */
  config: CallApiExtraOptions & CallApiRequestOptions;
  /**
   * Merged options consisting of extra options from createFetchClient, the callApi instance and default options.
   *
   */
  options: CallApiExtraOptionsForHooks;
  /**
   * Merged request consisting of request options from createFetchClient, the callApi instance and default request options.
   */
  request: CallApiRequestOptionsForHooks;
};
type ValidationErrorContext = UnmaskType<RequestContext & {
  error: ValidationError;
  response: Response | null;
}>;
type SuccessContext<TData> = UnmaskType<RequestContext & {
  data: TData;
  response: Response;
}>;
type ResponseContext<TData, TErrorData> = UnmaskType<RequestContext & ({
  data: NoInfer<TData>;
  error: null;
  response: Response;
} | {
  data: null;
  error: PossibleHTTPError<TErrorData>;
  response: Response;
})>;
type RequestErrorContext = RequestContext & {
  error: PossibleJavaScriptOrValidationError;
  response: null;
};
type ErrorContext<TErrorData> = UnmaskType<RequestContext & ({
  error: PossibleHTTPError<TErrorData>;
  response: Response;
} | {
  error: PossibleJavaScriptOrValidationError;
  response: Response | null;
})>;
type ResponseErrorContext<TErrorData> = UnmaskType<Extract<ErrorContext<TErrorData>, {
  error: PossibleHTTPError<TErrorData>;
}> & RequestContext>;
type RetryContext<TErrorData> = UnmaskType<ErrorContext<TErrorData> & {
  retryAttemptCount: number;
}>;
type RequestStreamContext = UnmaskType<RequestContext & {
  event: StreamProgressEvent;
  requestInstance: Request;
}>;
type ResponseStreamContext = UnmaskType<RequestContext & {
  event: StreamProgressEvent;
  response: Response;
}>;
//#endregion
//#region src/dedupe.d.ts
type DedupeOptions = {
  /**
   * Defines the scope of the deduplication cache, can be set to "global" | "local".
   * - If set to "global", the deduplication cache will be shared across all requests, regardless of whether they shared the same `createFetchClient` or not.
   * - If set to "local", the deduplication cache will be scoped to the current request.
   * @default "local"
   */
  dedupeCacheScope?: "global" | "local";
  /**
   * Custom request key to be used to identify a request in the fetch deduplication strategy.
   * @default the full request url + string formed from the request options
   */
  dedupeKey?: string;
  /**
   * Defines the deduplication strategy for the request, can be set to "none" | "defer" | "cancel".
   * - If set to "cancel", the previous pending request with the same request key will be cancelled and lets the new request through.
   * - If set to "defer", all new request with the same request key will be share the same response, until the previous one is completed.
   * - If set to "none", deduplication is disabled.
   * @default "cancel"
   */
  dedupeStrategy?: "cancel" | "defer" | "none";
};
//#endregion
//#region src/retry.d.ts
type RetryCondition<TErrorData> = (context: ErrorContext<TErrorData>) => Awaitable<boolean>;
type InnerRetryKeys<TErrorData> = Exclude<keyof RetryOptions<TErrorData>, "~retryAttemptCount" | "retry">;
type InnerRetryOptions<TErrorData> = { [Key in InnerRetryKeys<TErrorData> as Key extends `retry${infer TRest}` ? Uncapitalize<TRest> extends "attempts" ? never : Uncapitalize<TRest> : Key]?: RetryOptions<TErrorData>[Key] } & {
  attempts: NonNullable<RetryOptions<TErrorData>["retryAttempts"]>;
};
interface RetryOptions<TErrorData> {
  /**
   * Keeps track of the number of times the request has already been retried
   *
   * @deprecated **NOTE**: This property is used internally to track retries. Please abstain from modifying it.
   */
  readonly ["~retryAttemptCount"]?: number;
  /**
   * All retry options in a single object instead of separate properties
   */
  retry?: InnerRetryOptions<TErrorData>;
  /**
   * Number of allowed retry attempts on HTTP errors
   * @default 0
   */
  retryAttempts?: number;
  /**
   * Callback whose return value determines if a request should be retried or not
   */
  retryCondition?: RetryCondition<TErrorData>;
  /**
   * Delay between retries in milliseconds
   * @default 1000
   */
  retryDelay?: number | ((currentAttemptCount: number) => number);
  /**
   * Maximum delay in milliseconds. Only applies to exponential strategy
   * @default 10000
   */
  retryMaxDelay?: number;
  /**
   * HTTP methods that are allowed to retry
   * @default ["GET", "POST"]
   */
  retryMethods?: MethodUnion[];
  /**
   * HTTP status codes that trigger a retry
   */
  retryStatusCodes?: number[];
  /**
   * Strategy to use when retrying
   * @default "linear"
   */
  retryStrategy?: "exponential" | "linear";
}
//#endregion
//#region src/types/conditional-types.d.ts
/**
 * @description Makes a type required if the output type of TSchema contains undefined, otherwise keeps it as is
 */
type MakeSchemaOptionRequired<TSchema extends CallApiSchema[keyof CallApiSchema], TObject> = undefined extends InferSchemaResult<TSchema, undefined> ? TObject : Required<TObject>;
type ApplyURLBasedConfig<TSchemaConfig extends CallApiSchemaConfig, TCurrentRouteKeys extends string> = TSchemaConfig["baseURL"] extends string ? `${TSchemaConfig["baseURL"]}${TCurrentRouteKeys}` : TCurrentRouteKeys;
type ApplyStrictConfig<TSchemaConfig extends CallApiSchemaConfig, TCurrentRouteKeys extends string> = TSchemaConfig["strict"] extends true ? TCurrentRouteKeys : TCurrentRouteKeys | AnyString;
type ApplySchemaConfiguration<TSchemaConfig extends CallApiSchemaConfig, TCurrentRouteKeys extends string> = ApplyStrictConfig<TSchemaConfig, ApplyURLBasedConfig<TSchemaConfig, TCurrentRouteKeys>>;
type InferAllRouteKeys<TBaseSchema extends BaseCallApiSchema, TSchemaConfig extends CallApiSchemaConfig> = ApplySchemaConfiguration<TSchemaConfig, keyof TBaseSchema extends string ? keyof TBaseSchema : never>;
type InferInitURL<TBaseSchema extends BaseCallApiSchema, TSchemaConfig extends CallApiSchemaConfig> = InferAllRouteKeys<TBaseSchema, TSchemaConfig> | URL;
type GetCurrentRouteKey<TSchemaConfig extends CallApiSchemaConfig, TPath> = TSchemaConfig["baseURL"] extends string ? TPath extends `${TSchemaConfig["baseURL"]}${infer TCurrentRoute}` ? TCurrentRoute extends string ? TCurrentRoute : string : string : TPath extends URL ? string : TPath;
type JsonPrimitive = boolean | number | string | null | undefined;
type SerializableObject = Record<keyof object, unknown>;
type SerializableArray = Array<JsonPrimitive | SerializableArray | SerializableObject> | ReadonlyArray<JsonPrimitive | SerializableArray | SerializableObject>;
type Body = UnmaskType<RequestInit["body"] | SerializableArray | SerializableObject>;
type InferBodyOption<TSchema extends CallApiSchema> = MakeSchemaOptionRequired<TSchema["body"], {
  /**
   * Body of the request, can be a object or any other supported body type.
   */
  body?: InferSchemaResult<TSchema["body"], Body>;
}>;
type MethodUnion = UnmaskType<"CONNECT" | "DELETE" | "GET" | "HEAD" | "OPTIONS" | "PATCH" | "POST" | "PUT" | "TRACE" | AnyString>;
type InferMethodFromURL<TInitURL> = TInitURL extends `@${infer TMethod extends RouteKeyMethods}/${string}` ? Uppercase<TMethod> : MethodUnion;
type MakeMethodOptionRequired<TInitURL, TSchemaConfig extends CallApiSchemaConfig, TObject> = undefined extends TSchemaConfig ? TObject : TInitURL extends `@${string}/${string}` ? TSchemaConfig["requireHttpMethodProvision"] extends true ? Required<TObject> : TObject : TObject;
type InferMethodOption<TSchema extends CallApiSchema, TSchemaConfig extends CallApiSchemaConfig, TInitURL> = MakeSchemaOptionRequired<TSchema["method"], MakeMethodOptionRequired<TInitURL, TSchemaConfig, {
  /**
   * HTTP method for the request.
   * @default "GET"
   */
  method?: InferSchemaResult<TSchema["method"], InferMethodFromURL<TInitURL>>;
}>>;
type HeadersOption = UnmaskType<Record<"Authorization", CommonAuthorizationHeaders | undefined> | Record<"Content-Type", CommonContentTypes | undefined> | Record<CommonRequestHeaders, string | undefined> | Record<string, string | undefined> | Array<[string, string]>>;
type InferHeadersOption<TSchema extends CallApiSchema> = MakeSchemaOptionRequired<TSchema["headers"], {
  /**
   * Headers to be used in the request.
   */
  headers?: InferSchemaResult<TSchema["headers"], HeadersOption> | ((context: {
    baseHeaders: NonNullable<HeadersOption>;
  }) => InferSchemaResult<TSchema["headers"], HeadersOption>);
}>;
type InferRequestOptions<TSchema extends CallApiSchema, TSchemaConfig extends CallApiSchemaConfig, TInitURL extends InferInitURL<BaseCallApiSchema, CallApiSchemaConfig>> = InferBodyOption<TSchema> & InferHeadersOption<TSchema> & InferMethodOption<TSchema, TSchemaConfig, TInitURL>;
interface Register {}
type GlobalMeta = Register extends {
  meta?: infer TMeta extends Record<string, unknown>;
} ? TMeta : never;
type InferMetaOption<TSchema extends CallApiSchema> = MakeSchemaOptionRequired<TSchema["meta"], {
  meta?: InferSchemaResult<TSchema["meta"], GlobalMeta>;
}>;
type InferQueryOption<TSchema extends CallApiSchema> = MakeSchemaOptionRequired<TSchema["query"], {
  /**
   * Parameters to be appended to the URL (i.e: /:id)
   */
  query?: InferSchemaResult<TSchema["query"], Query>;
}>;
type EmptyString = "";
type InferParamFromRoute<TRoute> = TRoute extends `${infer IgnoredPrefix}:${infer TCurrentParam}/${infer TRemainingPath}` ? TCurrentParam extends EmptyString ? InferParamFromRoute<TRemainingPath> : Prettify<Record<TCurrentParam | (Params extends InferParamFromRoute<TRemainingPath> ? never : keyof Extract<InferParamFromRoute<TRemainingPath>, Record<string, unknown>>), AllowedQueryParamValues>> | [AllowedQueryParamValues, ...(Params extends InferParamFromRoute<TRemainingPath> ? [] : Extract<InferParamFromRoute<TRemainingPath>, unknown[]>)] : TRoute extends `${infer IgnoredPrefix}:${infer TCurrentParam}` ? TCurrentParam extends EmptyString ? Params : Prettify<Record<TCurrentParam, AllowedQueryParamValues>> | [AllowedQueryParamValues] : Params;
type InferParamsOption<TSchema extends CallApiSchema, TCurrentRouteKey> = MakeSchemaOptionRequired<TSchema["params"], {
  /**
   * Parameters to be appended to the URL (i.e: /:id)
   */
  params?: InferSchemaResult<TSchema["params"], InferParamFromRoute<TCurrentRouteKey>>;
}>;
type InferExtraOptions<TSchema extends CallApiSchema, TCurrentRouteKey> = InferMetaOption<TSchema> & InferParamsOption<TSchema, TCurrentRouteKey> & InferQueryOption<TSchema>;
type InferPluginOptions<TPluginArray extends CallApiPlugin[]> = UnionToIntersection<TPluginArray extends Array<infer TPlugin> ? TPlugin extends CallApiPlugin ? TPlugin["defineExtraOptions"] extends AnyFunction<infer TResult> ? InferSchemaResult<TResult> : never : never : never>;
type ExtractKeys<TUnion, TSelectedUnion extends TUnion> = Extract<TUnion, TSelectedUnion>;
type ResultModeOption<TErrorData, TResultMode extends ResultModeUnion> = TErrorData extends false ? {
  resultMode: "onlySuccessWithException";
} : TErrorData extends false | undefined ? {
  resultMode?: "onlySuccessWithException";
} : TErrorData extends false | null ? {
  resultMode?: ExtractKeys<ResultModeUnion, "onlySuccess" | "onlySuccessWithException">;
} : null extends TResultMode ? {
  resultMode?: TResultMode;
} : {
  resultMode: TResultMode;
};
type ThrowOnErrorUnion = boolean;
type ThrowOnErrorOption<TErrorData, TThrowOnError extends ThrowOnErrorUnion> = TErrorData extends false ? {
  throwOnError: true;
} : TErrorData extends false | undefined ? {
  throwOnError?: true;
} : {
  throwOnError?: TThrowOnError | ((context: ErrorContext<TErrorData>) => TThrowOnError);
};
//#endregion
//#region src/types/common.d.ts
type FetchSpecificKeysUnion = Exclude<(typeof fetchSpecificKeys)[number], "body" | "headers" | "method">;
type ModifiedRequestInit = RequestInit & {
  duplex?: "half";
};
type CallApiRequestOptions = Prettify<{
  /**
   * Body of the request, can be a object or any other supported body type.
   */
  body?: Body;
  /**
   * Headers to be used in the request.
   */
  headers?: HeadersOption;
  /**
   * HTTP method for the request.
   * @default "GET"
   */
  method?: MethodUnion;
} & Pick<ModifiedRequestInit, FetchSpecificKeysUnion>>;
type CallApiRequestOptionsForHooks = Omit<CallApiRequestOptions, "headers"> & {
  headers: Record<string, string | undefined>;
};
type FetchImpl = UnmaskType<(input: string | Request | URL, init?: RequestInit) => Promise<Response>>;
type SharedExtraOptions<TData = DefaultDataType, TErrorData = DefaultDataType, TResultMode extends ResultModeUnion = ResultModeUnion, TThrowOnError extends ThrowOnErrorUnion = DefaultThrowOnError, TResponseType extends ResponseTypeUnion = ResponseTypeUnion, TPluginArray extends CallApiPlugin[] = DefaultPluginArray> = DedupeOptions & HooksOrHooksArray<TData, TErrorData, Partial<InferPluginOptions<TPluginArray>>> & Partial<InferPluginOptions<TPluginArray>> & ResultModeOption<TErrorData, TResultMode> & RetryOptions<TErrorData> & ThrowOnErrorOption<TErrorData, TThrowOnError> & URLOptions & {
  /**
   * Authorization header value.
   */
  auth?: string | Auth | null;
  /**
   * Base URL for the request.
   */
  baseURL?: string;
  /**
   * Custom function to serialize the body object into a string.
   */
  bodySerializer?: (bodyData: Record<string, unknown>) => string;
  /**
   * Whether or not to clone the response, so response.json() and the like can be read again else where.
   * @see https://developer.mozilla.org/en-US/docs/Web/API/Response/clone
   * @default false
   */
  cloneResponse?: boolean;
  /**
   * Custom fetch implementation
   */
  customFetchImpl?: FetchImpl;
  /**
   * Default error message to use if none is provided from a response.
   * @default "Failed to fetch data from server!"
   */
  defaultErrorMessage?: string;
  /**
   * If true, forces the calculation of the total byte size from the request or response body, in case the content-length header is not present or is incorrect.
   * @default false
   */
  forcefullyCalculateStreamSize?: boolean | {
    request?: boolean;
    response?: boolean;
  };
  /**
   * Defines the mode in which the composed hooks are executed".
   * - If set to "parallel", main and plugin hooks will be executed in parallel.
   * - If set to "sequential", the plugin hooks will be executed first, followed by the main hook.
   * @default "parallel"
   */
  mergedHooksExecutionMode?: "parallel" | "sequential";
  /**
   * - Controls what order in which the composed hooks execute
   * @default "mainHooksAfterPlugins"
   */
  mergedHooksExecutionOrder?: "mainHooksAfterPlugins" | "mainHooksBeforePlugins";
  /**
   * - An optional field you can fill with additional information,
   * to associate with the request, typically used for logging or tracing.
   *
   * - A good use case for this, would be to use the info to handle specific cases in any of the shared interceptors.
   *
   * @example
   * ```ts
   * const callMainApi = callApi.create({
   * 	baseURL: "https://main-api.com",
   * 	onResponseError: ({ response, options }) => {
   * 		if (options.meta?.userId) {
   * 			console.error(`User ${options.meta.userId} made an error`);
   * 		}
   * 	},
   * });
   *
   * const response = await callMainApi({
   * 	url: "https://example.com/api/data",
   * 	meta: { userId: "123" },
   * });
   * ```
   */
  meta?: GlobalMeta;
  /**
   * Custom function to parse the response string
   */
  responseParser?: (responseString: string) => Awaitable<Record<string, unknown>>;
  /**
   * Expected response type, affects how response is parsed
   * @default "json"
   */
  responseType?: TResponseType;
  /**
   * Mode of the result, can influence how results are handled or returned.
   * Can be set to "all" | "onlySuccess" | "onlyError" | "onlyResponse".
   * @default "all"
   */
  resultMode?: TResultMode;
  /**
   * If true or the function returns true, throws errors instead of returning them
   * The function is passed the error object and can be used to conditionally throw the error
   * @default false
   */
  throwOnError?: TThrowOnError;
  /**
   * Request timeout in milliseconds
   */
  timeout?: number;
};
type BaseCallApiExtraOptions<TBaseData = DefaultDataType, TBaseErrorData = DefaultDataType, TBaseResultMode extends ResultModeUnion = ResultModeUnion, TBaseThrowOnError extends ThrowOnErrorUnion = DefaultThrowOnError, TBaseResponseType extends ResponseTypeUnion = ResponseTypeUnion, TBasePluginArray extends CallApiPlugin[] = DefaultPluginArray, TBaseSchema extends BaseCallApiSchema = BaseCallApiSchema, TBaseSchemaConfig extends CallApiSchemaConfig = CallApiSchemaConfig> = SharedExtraOptions<TBaseData, TBaseErrorData, TBaseResultMode, TBaseThrowOnError, TBaseResponseType, TBasePluginArray> & {
  /**
   * An array of base callApi plugins. It allows you to extend the behavior of the library.
   */
  plugins?: TBasePluginArray;
  /**
   * Base schemas for the client.
   */
  schema?: Writeable<TBaseSchema, "deep">;
  /**
   * Schema Configuration
   */
  schemaConfig?: Writeable<TBaseSchemaConfig, "deep">;
  /**
   * Specifies which configuration parts should skip automatic merging between base and main configs.
   * Use this when you need manual control over how configs are combined.
   *
   * @enum
   * - `"all"` - Disables automatic merging for both request and options
   * - `"options"` - Disables automatic merging of options only
   * - `"request"` - Disables automatic merging of request only
   *
   * **Example**
   *
   * ```ts
   * const client = createFetchClient((ctx) => ({
   *   skipAutoMergeFor: "options",
   *
   *   // Now you can manually merge options in your config function
   *   ...ctx.options,
   * }));
   * ```
   */
  skipAutoMergeFor?: "all" | "options" | "request";
};
type CallApiExtraOptions<TData = DefaultDataType, TErrorData = DefaultDataType, TResultMode extends ResultModeUnion = ResultModeUnion, TThrowOnError extends ThrowOnErrorUnion = DefaultThrowOnError, TResponseType extends ResponseTypeUnion = ResponseTypeUnion, TBasePluginArray extends CallApiPlugin[] = DefaultPluginArray, TPluginArray extends CallApiPlugin[] = DefaultPluginArray, TBaseSchema extends BaseCallApiSchema = BaseCallApiSchema, TSchema extends CallApiSchema = CallApiSchema, TBaseSchemaConfig extends CallApiSchemaConfig = CallApiSchemaConfig, TSchemaConfig extends CallApiSchemaConfig = CallApiSchemaConfig, TCurrentRouteKey extends string = string> = SharedExtraOptions<TData, TErrorData, TResultMode, TThrowOnError, TResponseType, TPluginArray> & {
  /**
   * An array of instance CallApi plugins. It allows you to extend the behavior of the library.
   */
  plugins?: TPluginArray | ((context: {
    basePlugins: TBasePluginArray;
  }) => TPluginArray);
  /**
   * Schemas for the callapi instance
   */
  schema?: Writeable<TSchema, "deep"> | ((context: {
    baseSchema: Writeable<TBaseSchema, "deep">;
    currentRouteSchema: NonNullable<Writeable<TBaseSchema[TCurrentRouteKey], "deep">>;
  }) => Writeable<TSchema, "deep">);
  /**
   * Schema config for the callapi instance
   */
  schemaConfig?: Writeable<TSchemaConfig, "deep"> | ((context: {
    baseSchemaConfig: NonNullable<Writeable<TBaseSchemaConfig, "deep">>;
  }) => Writeable<TSchemaConfig, "deep">);
};
type CallApiExtraOptionsForHooks = Hooks & Omit<CallApiExtraOptions, keyof Hooks>;
type BaseCallApiConfig<TBaseData = DefaultDataType, TBaseErrorData = DefaultDataType, TBaseResultMode extends ResultModeUnion = ResultModeUnion, TBaseThrowOnError extends ThrowOnErrorUnion = DefaultThrowOnError, TBaseResponseType extends ResponseTypeUnion = ResponseTypeUnion, TBaseSchema extends BaseCallApiSchema = BaseCallApiSchema, TBaseSchemaConfig extends CallApiSchemaConfig = CallApiSchemaConfig, TBasePluginArray extends CallApiPlugin[] = DefaultPluginArray> = (CallApiRequestOptions & BaseCallApiExtraOptions<TBaseData, TBaseErrorData, TBaseResultMode, TBaseThrowOnError, TBaseResponseType, TBasePluginArray, TBaseSchema, TBaseSchemaConfig>) | ((context: {
  initURL: string;
  options: CallApiExtraOptions;
  request: CallApiRequestOptions;
}) => CallApiRequestOptions & BaseCallApiExtraOptions<TBaseData, TBaseErrorData, TBaseResultMode, TBaseThrowOnError, TBaseResponseType, TBasePluginArray, TBaseSchema, TBaseSchemaConfig>);
type CallApiConfig<TData = DefaultDataType, TErrorData = DefaultDataType, TResultMode extends ResultModeUnion = ResultModeUnion, TThrowOnError extends ThrowOnErrorUnion = DefaultThrowOnError, TResponseType extends ResponseTypeUnion = ResponseTypeUnion, TBaseSchema extends BaseCallApiSchema = BaseCallApiSchema, TSchema extends CallApiSchema = CallApiSchema, TBaseSchemaConfig extends CallApiSchemaConfig = CallApiSchemaConfig, TSchemaConfig extends CallApiSchemaConfig = CallApiSchemaConfig, TInitURL extends InferInitURL<BaseCallApiSchema, TSchemaConfig> = InferInitURL<BaseCallApiSchema, TSchemaConfig>, TCurrentRouteKey extends string = string, TBasePluginArray extends CallApiPlugin[] = DefaultPluginArray, TPluginArray extends CallApiPlugin[] = DefaultPluginArray> = InferExtraOptions<TSchema, TCurrentRouteKey> & InferRequestOptions<TSchema, TSchemaConfig, TInitURL> & Omit<CallApiExtraOptions<TData, TErrorData, TResultMode, TThrowOnError, TResponseType, TBasePluginArray, TPluginArray, TBaseSchema, TSchema, TBaseSchemaConfig, TSchemaConfig, TCurrentRouteKey>, keyof InferExtraOptions<CallApiSchema, string>> & Omit<CallApiRequestOptions, keyof InferRequestOptions<CallApiSchema, CallApiSchemaConfig, string>>;
type CallApiParameters<TData = DefaultDataType, TErrorData = DefaultDataType, TResultMode extends ResultModeUnion = ResultModeUnion, TThrowOnError extends ThrowOnErrorUnion = DefaultThrowOnError, TResponseType extends ResponseTypeUnion = ResponseTypeUnion, TBaseSchema extends BaseCallApiSchema = BaseCallApiSchema, TSchema extends CallApiSchema = CallApiSchema, TBaseSchemaConfig extends CallApiSchemaConfig = CallApiSchemaConfig, TSchemaConfig extends CallApiSchemaConfig = CallApiSchemaConfig, TInitURL extends InferInitURL<BaseCallApiSchema, TSchemaConfig> = InferInitURL<BaseCallApiSchema, TSchemaConfig>, TCurrentRouteKey extends string = string, TBasePluginArray extends CallApiPlugin[] = DefaultPluginArray, TPluginArray extends CallApiPlugin[] = DefaultPluginArray> = [initURL: TInitURL, config?: CallApiConfig<TData, TErrorData, TResultMode, TThrowOnError, TResponseType, TBaseSchema, TSchema, TBaseSchemaConfig, TSchemaConfig, TInitURL, TCurrentRouteKey, TBasePluginArray, TPluginArray>];
type CallApiResult<TData, TErrorData, TResultMode extends ResultModeUnion, TThrowOnError extends ThrowOnErrorUnion, TResponseType extends ResponseTypeUnion> = Promise<GetCallApiResult<TData, TErrorData, TResultMode, TThrowOnError, TResponseType>>;
//#endregion
export { AnyString, BaseCallApiConfig, BaseCallApiExtraOptions, BaseCallApiSchema, CallApiConfig, CallApiExtraOptions, CallApiExtraOptionsForHooks, CallApiParameters, CallApiPlugin, CallApiRequestOptions, CallApiRequestOptionsForHooks, CallApiResult, CallApiResultErrorVariant, CallApiResultSuccessVariant, CallApiSchema, CallApiSchemaConfig, DedupeOptions, DefaultDataType, DefaultPluginArray, DefaultThrowOnError, ErrorContext, GetCurrentRouteKey, HTTPError, Hooks, HooksOrHooksArray, InferInitURL, InferParamFromRoute, InferSchemaResult, PluginExtraOptions, PluginHooks, PluginHooksWithMoreOptions, PluginInitContext, PossibleHTTPError, PossibleJavaScriptError, PossibleJavaScriptOrValidationError, PossibleValidationError, Register, RequestContext, RequestStreamContext, ResponseContext, ResponseErrorContext, ResponseStreamContext, ResponseTypeUnion, ResultModeUnion, RetryOptions, SuccessContext, ThrowOnErrorUnion, URLOptions, ValidationError, definePlugin, defineSchema };
//# sourceMappingURL=common-4wwVi8vR.d.ts.map